@@ -1,7 +1,7 @@
 import typing_extensions
 
 from openapi_streams.apis.tags import TagValues
-from openapi_streams.apis.tags.evm_api import EvmApi
+from openapi_streams.apis.tags.evm_streams_api import EvmStreamsApi
 from openapi_streams.apis.tags.history_api import HistoryApi
 from openapi_streams.apis.tags.project_api import ProjectApi
 from openapi_streams.apis.tags.stats_api import StatsApi
@@ -9,7 +9,7 @@ from openapi_streams.apis.tags.stats_api import StatsApi
 TagToApi = typing_extensions.TypedDict(
     'TagToApi',
     {
-        TagValues.EVM: EvmApi,
+        TagValues.EVM_STREAMS: EvmStreamsApi,
         TagValues.HISTORY: HistoryApi,
         TagValues.PROJECT: ProjectApi,
         TagValues.STATS: StatsApi,
@@ -18,7 +18,7 @@ TagToApi = typing_extensions.TypedDict(
 
 tag_to_api = TagToApi(
     {
-        TagValues.EVM: EvmApi,
+        TagValues.EVM_STREAMS: EvmStreamsApi,
         TagValues.HISTORY: HistoryApi,
         TagValues.PROJECT: ProjectApi,
         TagValues.STATS: StatsApi,
